@@ -1,4 +1,4 @@
-__version__ = '0.5.4'
+__version__ = '0.5.7'
 
 from symgroupy import symgrouplib
 import numpy as np
@@ -28,7 +28,7 @@ def _get_connectivity_vector(connect, na, central_atom=0):
 class Symgroupy:
     def __init__(self,
                  coordinates,                # coordinates in angstrom
-                 group,                      # symmetry point group
+                 group,                      # point symmetry group
                  multi=1,                    # multiple measures
                  labels=None,                # atomic symbols (or other representative labels)
                  central_atom=None,          # Atom number that contains the center atom (if exist)
@@ -42,16 +42,21 @@ class Symgroupy:
             central_atom = 0
 
         operation = group[0].lower().encode('ascii')
+
+        # check if valid group label
+        if group[0].lower() not in ['c', 'e', 'i', 'r', 's']:
+            raise Exception('wrong symmetry group label: "{}"'.format(group))
+
         try:
             operation_axis = int(group[1:])
         except ValueError:
-            if group in ['cs', 'ci']:
-                operation = {'cs': 'r', 'ci': 'i'}[group]
+            if group.lower() in ['cs', 'ci']:
+                operation = {'cs': 'r', 'ci': 'i'}[group.lower()]
                 operation_axis = -1
             elif operation in [b'i', b'r', b'e']:  # accepted operations
                 operation_axis = 0
             else:
-                raise Exception('Wrong symmetry label')
+                raise Exception('wrong symmetry group label: "{}"'.format(group))
 
         if center is None:
             center = np.average(coordinates, axis=0)
@@ -116,7 +121,7 @@ class Symgroupy:
         return self._reference_axis
 
     @property
-    def cms_multi(self):
+    def csm_multi(self):
         return self._csm_multi
 
     @property
@@ -163,8 +168,8 @@ if __name__ == '__main__':
     print(fen4.nearest_structure)
     print('Reference axis')
     print(fen4.reference_axis)
-    print('multi CMS')
-    print(fen4.cms_multi)
+    print('multi CSM')
+    print(fen4.csm_multi)
     print('multi axis')
     print(fen4.axis_multi)
     print('center', fen4.center)
@@ -196,8 +201,8 @@ if __name__ == '__main__':
     print(measure.nearest_structure)
     print('Reference axis')
     print(measure.reference_axis)
-    print('multi CMS')
-    print(measure.cms_multi)
+    print('multi CSM')
+    print(measure.csm_multi)
     print('multi axis')
     print(measure.axis_multi)
 
@@ -234,7 +239,7 @@ if __name__ == '__main__':
     print(measure.nearest_structure)
     print('Reference axis')
     print(measure.reference_axis)
-    print('multi CMS')
-    print(measure.cms_multi)
+    print('multi CSM')
+    print(measure.csm_multi)
     print('multi axis')
     print(measure.axis_multi)
